==> ckeditor_4.5.7+dfsg.orig.tar.xz: ckeditor-dev-4.5.7/plugins/link/lang/bn.js <==
/*
Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'bn', {
	acccessKey: 'এক্সেস কী',
	advanced: 'এডভান্সড',
	advisoryContentType: 'পরামর্শ কন্টেন্টের প্রকার',
	advisoryTitle: 'পরামর্শ শীর্ষক',
	anchor: {
		toolbar: 'নোঙ্গর',
		menu: 'নোঙর প্রোপার্টি',
		title: 'নোঙর প্রোপার্টি',
		name: 'নোঙরের নাম',
		errorName: 'নোঙরের নাম টাইপ করুন',
		remove: 'Remove Anchor'
	},
	anchorId: 'নোঙরের আইডি দিয়ে',
	anchorName: 'নোঙরের নাম দিয়ে',
	charset: 'লিংক রিসোর্স ক্যারেক্টর সেট',
	cssClasses: 'স্টাইল-শীট ক্লাস',
	emailAddress: 'ইমেইল ঠিকানা',
	emailBody: 'মেসেজের দেহ',
	emailSubject: 'মেসেজের বিষয়',
	id: 'আইডি',
	info: 'লিংক তথ্য',
	langCode: 'ভাষা লেখার দিক',
	langDir: 'ভাষা লেখার দিক',
	langDirLTR: 'বাম থেকে ডান (LTR)',
	langDirRTL: 'ডান থেকে বাম (RTL)',
	menu: 'লিংক সম্পাদন',
	name: 'নাম',
	noAnchors: '(No anchors available in the document)', // MISSING
	noEmail: 'অনুগ্রহ করে ইমেইল এড্রেস টাইপ করুন',
	noUrl: 'অনুগ্রহ করে URL লিংক টাইপ করুন',
	other: '<other>', // MISSING
	popupDependent: 'ডিপেন্ডেন্ট (Netscape)',
	popupFeatures: 'পপআপ উইন্ডো ফীচার সমূহ',
	popupFullScreen: 'পূর্ণ পর্দা জুড়ে (IE)',
	popupLeft: 'বামের পজিশন',
	popupLocationBar: 'লোকেশন বার',
	popupMenuBar: 'মেন্যু বার',
	popupResizable: 'Resizable', // MISSING
	popupScrollBars: 'স্ক্রল বার',
	popupStatusBar: 'স্ট্যাটাস বার',
	popupToolbar: 'টুল বার',
	popupTop: 'ডানের পজিশন',
	rel: 'Relationship', // MISSING
	selectAnchor: 'নোঙর বাছাই',
	styles: 'স্টাইল',
	tabIndex: 'ট্যাব ইন্ডেক্স',
	target: 'টার্গেট',
	targetFrame: '<ফ্রেম>',
	targetFrameName: 'টার্গেট ফ্রেমের নাম',
	targetPopup: '<পপআপ উইন্ডো>',
	targetPopupName: 'পপআপ উইন্ডোর নাম',
	title: 'লিংক',
	toAnchor: 'এই পেজে নোঙর কর',
	toEmail: 'ইমেইল',
	toUrl: 'URL',
	toolbar: 'লিংক যুক্ত কর',
	type: 'লিংক প্রকার',
	unlink: 'লিংক সরাও',
	upload: 'আপলোড'
} );

==> ckeditor_4.11.1+dfsg.orig.tar.xz: ckeditor-dev-4.11.1/plugins/link/lang/bn.js <==
﻿/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'bn', {
	acccessKey: 'প্রবেশ কী',
	advanced: 'এডভান্সড',
	advisoryContentType: 'পরামর্শ কন্টেন্টের প্রকার',
	advisoryTitle: 'পরামর্শ শীর্ষক',
	anchor: {
		toolbar: 'নোঙ্গর',
		menu: 'নোঙর প্রোপার্টি',
		title: 'নোঙর প্রোপার্টি',
		name: 'নোঙরের নাম',
		errorName: 'নোঙরের নাম টাইপ করুন',
		remove: 'Remove Anchor'
	},
	anchorId: 'নোঙরের আইডি দিয়ে',
	anchorName: 'নোঙরের নাম দিয়ে',
	charset: 'লিংক রিসোর্স ক্যারেক্টর সেট',
	cssClasses: 'স্টাইল-শীট ক্লাস',
	download: 'Force Download', // MISSING
	displayText: 'Display Text', // MISSING
	emailAddress: 'ইমেইল ঠিকানা',
	emailBody: 'মেসেজের দেহ',
	emailSubject: 'মেসেজের বিষয়',
	id: 'আইডি',
	info: 'লিংক তথ্য',
	langCode: 'ভাষা লেখার দিক',
	langDir: 'ভাষা লেখার দিক',
	langDirLTR: 'বাম থেকে ডান (LTR)',
	langDirRTL: 'ডান থেকে বাম (RTL)',
	menu: 'লিংক সম্পাদন',
	name: 'নাম',
	noAnchors: '(No anchors available in the document)', // MISSING
	noEmail: 'অনুগ্রহ করে ইমেইল এড্রেস টাইপ করুন',
	noUrl: 'অনুগ্রহ করে URL লিংক টাইপ করুন',
	noTel: 'Please type the phone number', // MISSING
	other: '<other>', // MISSING
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'ডিপেন্ডেন্ট (Netscape)',
	popupFeatures: 'পপআপ উইন্ডো ফীচার সমূহ',
	popupFullScreen: 'পূর্ণ পর্দা জুড়ে (IE)',
	popupLeft: 'বামের পজিশন',
	popupLocationBar: 'লোকেশন বার',
	popupMenuBar: 'মেন্যু বার',
	popupResizable: 'Resizable', // MISSING
	popupScrollBars: 'স্ক্রল বার',
	popupStatusBar: 'স্ট্যাটাস বার',
	popupToolbar: 'টুল বার',
	popupTop: 'ডানের পজিশন',
	rel: 'Relationship', // MISSING
	selectAnchor: 'নোঙর বাছাই',
	styles: 'স্টাইল',
	tabIndex: 'ট্যাব ইন্ডেক্স',
	target: 'টার্গেট',
	targetFrame: '<ফ্রেম>',
	targetFrameName: 'টার্গেট ফ্রেমের নাম',
	targetPopup: '<পপআপ উইন্ডো>',
	targetPopupName: 'পপআপ উইন্ডোর নাম',
	title: 'লিংক',
	toAnchor: 'এই পেজে নোঙর কর',
	toEmail: 'ইমেইল',
	toUrl: 'URL',
	toPhone: 'Phone', // MISSING
	toolbar: 'লিংক যুক্ত কর',
	type: 'লিংক প্রকার',
	unlink: 'লিংক সরাও',
	upload: 'আপলোড'
} );
